@@ -280,8 +280,8 @@ class HftBacktest:
                     or order.status == CANCELED:
                 del self.orders[order.order_id]
 
-    def get_add_data(self, item_num):
-        return self.user_data[item_num]
+    def get_user_data(self, event):
+        return self.user_data[event - USER_DEFINED_EVENT]
 
     def __get_start_timestamp(self):
         return self.data[0, COL_LOCAL_TIMESTAMP]
@@ -325,6 +325,9 @@ class HftBacktest:
             next_exch_timestamp = self.data[self.row_num + 1, COL_EXCH_TIMESTAMP]
             exch_timestamp = self.data[self.row_num, COL_EXCH_TIMESTAMP]
 
+            # exchange timestamp must be ahead of local timestamp.
+            # assert next_local_timestamp > next_exch_timestamp
+
             # A user order cannot be processed between the rows that have the same exchange timestamp.
             # These events happen all at once in an exchange.
             if exch_timestamp != next_exch_timestamp:
